package pEFL::Elm::Genlist;

use strict;
use warnings;

require Exporter;
use pEFL::Evas;
use pEFL::Elm::Object;

our @ISA = qw(Exporter ElmGenlistPtr);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

# This allows declaration	use pEFL::Elm ':all';
# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
# will save memory.
our %EXPORT_TAGS = ( 'all' => [ qw(

) ] );

our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );

our @EXPORT = qw(

);

require XSLoader;
XSLoader::load('pEFL::Elm::Genlist');

sub add {
    my ($class,$parent) = @_;
    my $widget = elm_genlist_add($parent);
    $widget->event_callback_add(EVAS_CALLBACK_DEL, \&pEFL::PLSide::cleanup, $widget);
    $widget->event_callback_add(EVAS_CALLBACK_DEL, \&pEFL::PLSide::cleanup_genitems, $widget);
    $widget->event_callback_add(EVAS_CALLBACK_DEL, \&pEFL::PLSide::cleanup_signals, $widget);
    return $widget;
}

*new = \&add;

package ElmGenlistPtr;

use pEFL::Eina;

our @ISA = qw(ElmScrollerPtr ElmObjectPtr EvasObjectPtr);

sub insert_before {
    my ($obj,$itc,$data,$parent,$before_it,$type,$func,$func_data) = @_;
    my $id = pEFL::PLSide::save_gen_item_data( $obj,$data,$func,$func_data );
    my $widget = _elm_genlist_item_insert_before($obj,$itc,$id,$parent,$before_it,$type);
    return $widget;
}

sub insert_after {
    my ($obj,$itc,$data,$parent,$before_it,$type,$func,$func_data) = @_;
    my $id = pEFL::PLSide::save_gen_item_data( $obj,$data,$func,$func_data );
    my $widget = _elm_genlist_item_insert_after($obj,$itc,$id,$parent,$before_it,$type);
    return $widget;
}

sub item_prepend {
    my ($obj,$itc,$data,$parent,$type,$func,$func_data) = @_;
    my $id = pEFL::PLSide::save_gen_item_data( $obj,$data,$func,$func_data );
    my $widget = _elm_genlist_item_prepend($obj,$itc,$id,$parent,$type);
    
    return $widget;
}

sub item_append {
    my ($obj,$itc,$data,$parent,$type,$func,$func_data) = @_;
    my $id = pEFL::PLSide::save_gen_item_data( $obj,$data,$func,$func_data );
    my $widget = _elm_genlist_item_append($obj,$itc,$id,$parent,$type);
    return $widget;
}

sub selected_items_get_pv {
    my ($obj) = @_;
    my $list = $obj->selected_items_get();
    my @array = pEFL::Eina::list2array($list,"ElmGenlistItemPtr");
    return @array;
}



# Preloaded methods go here.

1;
__END__

=head1 NAME

pEFL::Elm:Genlist

=head1 SYNOPSIS

  use pEFL::Elm;
  [...]
  my $widget = pEFL::Elm::Genlist->add($parent);
  $widget->item_append($item);
  my @selected = $widget->selected_items_get_pv();
  [...]

=head1 DESCRIPTION

This module is a perl binding to the Elementary Genlist widget.

For more informations see https://www.enlightenment.org/develop/legacy/api/c/start#group__Elm__Genlist.html 

For instructions, how to use pEFL::Elm::Genlist, please study this API reference for now. A perl-specific documentation will perhaps come in later versions. But applying the C documentation should be no problem. pEFL::Elm::Genlist gives you a nice object-oriented interface that is kept close to the C API. Please note, that the perl method names remove the "elm_genlist_" at the beginning of the c functions.

=head2 EXPORT

None by default.

=head1 SEE ALSO

https://www.enlightenment.org/develop/legacy/api/c/start#group__Elm__Genlist.html

=head1 AUTHOR

Maximilian Lika

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2021 by Maximilian Lika

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.28.1 or,
at your option, any later version of Perl 5 you may have available.


=cut
